@@ -30,6 +30,8 @@ class AppCommandResponsePattern:
 
     update_attribute: str = attr.ib(converter=str)
     add_zone: bool = attr.ib(converter=bool, default=True)
+    search_zone_text: bool = attr.ib(converter=bool, default=False)
+    prefix: str = attr.ib(converter=str, default="")
     suffix: str = attr.ib(converter=str, default="")
     get_xml_attribute: Optional[str] = attr.ib(
         converter=attr.converters.optional(str), default=None
@@ -73,7 +75,7 @@ class AppCommands:
     """Collect known AppCommand.xml tags."""
 
     GetAllZoneMuteStatus = AppCommandCmd(
-        cmd_id=1,
+        cmd_id="1",
         cmd_text="GetAllZoneMuteStatus",
         response_pattern=(
             AppCommandResponsePattern(
@@ -82,7 +84,7 @@ class AppCommands:
         ),
     )
     GetAllZonePowerStatus = AppCommandCmd(
-        cmd_id=1,
+        cmd_id="1",
         cmd_text="GetAllZonePowerStatus",
         response_pattern=(
             AppCommandResponsePattern(
@@ -91,7 +93,7 @@ class AppCommands:
         ),
     )
     GetAllZoneSource = AppCommandCmd(
-        cmd_id=1,
+        cmd_id="1",
         cmd_text="GetAllZoneSource",
         response_pattern=(
             AppCommandResponsePattern(
@@ -100,7 +102,7 @@ class AppCommands:
         ),
     )
     GetAllZoneVolume = AppCommandCmd(
-        cmd_id=1,
+        cmd_id="1",
         cmd_text="GetAllZoneVolume",
         response_pattern=(
             AppCommandResponsePattern(
@@ -109,8 +111,42 @@ class AppCommands:
         ),
     )
 
+    GetAutoStandby = AppCommandCmd(
+        cmd_id="1",
+        cmd_text="GetAutoStandby",
+        response_pattern=(
+            AppCommandResponsePattern(
+                update_attribute="_auto_standby",
+                add_zone=False,
+                search_zone_text=True,
+                prefix="/list/listvalue/",
+                suffix="/value",
+            ),
+        ),
+    )
+
+    GetDimmer = AppCommandCmd(
+        cmd_id="1",
+        cmd_text="GetDimmer",
+        response_pattern=(
+            AppCommandResponsePattern(
+                update_attribute="_dimmer", add_zone=False, suffix="/value"
+            ),
+        ),
+    )
+
+    GetECO = AppCommandCmd(
+        cmd_id="1",
+        cmd_text="GetECO",
+        response_pattern=(
+            AppCommandResponsePattern(
+                update_attribute="_eco_mode", add_zone=False, suffix="/mode"
+            ),
+        ),
+    )
+
     GetSurroundModeStatus = AppCommandCmd(
-        cmd_id=1,
+        cmd_id="1",
         cmd_text="GetSurroundModeStatus",
         response_pattern=(
             AppCommandResponsePattern(
@@ -120,7 +156,7 @@ class AppCommands:
     )
 
     GetToneControl = AppCommandCmd(
-        cmd_id=1,
+        cmd_id="1",
         cmd_text="GetToneControl",
         response_pattern=(
             AppCommandResponsePattern(
@@ -149,7 +185,7 @@ class AppCommands:
     )
     # Replace set command with a real command using attr.evolve
     SetToneControl = AppCommandCmd(
-        cmd_id=1,
+        cmd_id="1",
         cmd_text="SetToneControl",
         set_command=AppCommandCmdParam(name="REPLACE", text="REPLACE"),
     )
@@ -160,7 +196,7 @@ class AppCommands:
     GetFriendlyName = AppCommandCmd(cmd_id=1, cmd_text="GetFriendlyName")
 
     GetAudyssey = AppCommandCmd(
-        cmd_id=3,
+        cmd_id="3",
         name="GetAudyssey",
         param_list=(
             AppCommandCmdParam(name="dynamiceq"),
@@ -216,22 +252,22 @@ class AppCommands:
         ),
     )
     SetAudysseyDynamicEQ = AppCommandCmd(
-        cmd_id=3,
+        cmd_id="3",
         name="SetAudyssey",
         param_list=(AppCommandCmdParam(name="dynamiceq", text="REPLACE"),),
     )
     SetAudysseyMultiEQ = AppCommandCmd(
-        cmd_id=3,
+        cmd_id="3",
         name="SetAudyssey",
         param_list=(AppCommandCmdParam(name="multieq", text="REPLACE"),),
     )
     SetAudysseyReflevoffset = AppCommandCmd(
-        cmd_id=3,
+        cmd_id="3",
         name="SetAudyssey",
         param_list=(AppCommandCmdParam(name="reflevoffset", text="REPLACE"),),
     )
     SetAudysseyDynamicvol = AppCommandCmd(
-        cmd_id=3,
+        cmd_id="3",
         name="SetAudyssey",
         param_list=(AppCommandCmdParam(name="dynamicvol", text="REPLACE"),),
     )
