@@ -52,6 +52,7 @@ ReceiverURLs = namedtuple(
         "command_set_all_zone_stereo",
         "command_pause",
         "command_play",
+        "command_stop",
         "command_cusor_up",
         "command_cusor_down",
         "command_cusor_left",
@@ -122,6 +123,22 @@ ReceiverURLs = namedtuple(
         "command_dac_filter",  # Marantz Only
         "command_illumination",  # Marantz Only
         "command_auto_lip_sync",  # Marantz Only
+        "command_dolby_atmos_toggle_denon",
+        "command_dolby_atmos_toggle_marantz",
+        "command_page_up_denon",
+        "command_page_down_denon",
+        "command_page_up_marantz",
+        "command_page_down_marantz",
+        "command_input_mode_select_denon",
+        "command_input_mode_auto_denon",
+        "command_input_mode_hdmi_denon",
+        "command_input_mode_digital_denon",
+        "command_input_mode_analog_denon",
+        "command_input_mode_select_marantz",
+        "command_input_mode_auto_marantz",
+        "command_input_mode_hdmi_marantz",
+        "command_input_mode_digital_marantz",
+        "command_input_mode_analog_marantz",
     ],
 )
 TelnetCommands = namedtuple(
@@ -148,6 +165,7 @@ TelnetCommands = namedtuple(
         "command_set_all_zone_stereo",
         "command_pause",
         "command_play",
+        "command_stop",
         "command_multieq",
         "command_dynamiceq",
         "command_reflevoffset",
@@ -225,12 +243,28 @@ TelnetCommands = namedtuple(
         "command_dac_filter",  # Marantz Only
         "command_illumination",  # Marantz Only
         "command_auto_lip_sync",  # Marantz Only
+        "command_dolby_atmos_toggle_denon",
+        "command_dolby_atmos_toggle_marantz",
+        "command_page_up_denon",
+        "command_page_down_denon",
+        "command_page_up_marantz",
+        "command_page_down_marantz",
+        "command_input_mode_select_denon",
+        "command_input_mode_auto_denon",
+        "command_input_mode_hdmi_denon",
+        "command_input_mode_digital_denon",
+        "command_input_mode_analog_denon",
+        "command_input_mode_select_marantz",
+        "command_input_mode_auto_marantz",
+        "command_input_mode_hdmi_marantz",
+        "command_input_mode_digital_marantz",
+        "command_input_mode_analog_marantz",
     ],
 )
 
 # AVR-X search patterns
 DEVICEINFO_AVR_X_PATTERN = re.compile(
-    r"(.*AV(C|R)-(X|S|A).*|.*SR500[6-9]|.*SR60(07|08|09|10|11|12|13)|."
+    r"(.*AV([CR])-([XSA]).*|.*SR500[6-9]|.*SR60(07|08|09|10|11|12|13)|."
     r"*SR70(07|08|09|10|11|12|13)|.*SR501[3-4]|.*NR1604|.*NR1710)"
 )
 
@@ -325,39 +359,81 @@ ALL_ZONE_STEREO = "ALL ZONE STEREO"
 
 SOUND_MODE_MAPPING = {
     "MUSIC": [
+        "AAC+NEO:X M",
+        "AAC+PL2X M",
         "DOLBY D +NEO:X M",
+        "DOLBY D+ +NEO:X M",
+        "DOLBY D+ +PL2X M",
+        "DOLBY D+NEO:X M",
+        "DOLBY D+PL2X M",
+        "DOLBY HD+NEO:X M",
+        "DOLBY HD+PL2X M",
         "DOLBY PL2 M",
         "DOLBY PL2 MUSIC",
         "DOLBY PL2 X MUSIC",
+        "DOLBY PL2X M",
+        "DOLBY PLII MS",
+        "DTS HD+NEO:X M",
+        "DTS HD+PL2X M",
         "DTS NEO:6 M",
         "DTS NEO:6 MUSIC",
         "DTS NEO:X M",
         "DTS NEO:X MUSIC",
+        "DTS+NEO:X M",
+        "DTS+PL2X M",
+        "M CH IN+NEO:X M",
+        "M CH IN+PL2X M",
         "PLII MUSIC",
         "PLIIX MUSIC",
     ],
     "MOVIE": [
+        "AAC+NEO:X C",
+        "AAC+PL2X C",
         "DOLBY D +NEO:X C",
+        "DOLBY D+ +NEO:X C",
+        "DOLBY D+ +PL2X C",
+        "DOLBY D+NEO:X C",
+        "DOLBY D+PL2X C",
+        "DOLBY HD+NEO:X C",
+        "DOLBY HD+PL2X C",
         "DOLBY PL2 C",
         "DOLBY PL2 CINEMA",
         "DOLBY PL2 MOVIE",
         "DOLBY PL2 X MOVIE",
+        "DOLBY PL2X C",
         "DOLBY PLII MOVIE",
+        "DOLBY PLII MV",
+        "DTS HD+NEO:X C",
+        "DTS HD+PL2X C",
         "DTS NEO:6 C",
         "DTS NEO:6 CINEMA",
         "DTS NEO:X C",
         "DTS NEO:X CINEMA",
+        "DTS+NEO:X C",
+        "DTS+PL2X C",
+        "M CH IN+NEO:X C",
+        "M CH IN+PL2X C",
         "MULTI IN + VIRTUAL:X",
         "PLII CINEMA",
         "PLII MOVIE",
         "PLIIX CINEMA",
     ],
     "GAME": [
+        "AAC+NEO:X G",
         "DOLBY D +NEO:X G",
+        "DOLBY D+ +NEO:X G",
+        "DOLBY D+NEO:X G",
+        "DOLBY HD+NEO:X G",
         "DOLBY PL2 G",
         "DOLBY PL2 GAME",
         "DOLBY PL2 X GAME",
+        "DOLBY PL2X G",
         "DOLBY PLII GAME",
+        "DOLBY PLII GM",
+        "DTS HD+NEO:X G",
+        "DTS NEO:X G",
+        "DTS+NEO:X G",
+        "M CH IN+NEO:X G",
         "PLII GAME",
     ],
     "AUTO": ["None"],
@@ -368,27 +444,34 @@ SOUND_MODE_MAPPING = {
     "JAZZ CLUB": ["JAZZ CLUB"],
     "VIDEO GAME": ["VIDEO GAME"],
     "MONO MOVIE": ["MONO MOVIE"],
+    "SUPER STADIUM": ["SUPER STADIUM"],
+    "CLASSIC CONCERT": ["CLASSIC CONCERT"],
+    "WIDE SCREEN": ["WIDE SCREEN"],
     "DIRECT": ["DIRECT"],
     "PURE DIRECT": ["PURE_DIRECT", "PURE DIRECT"],
     "DOLBY DIGITAL": [
+        "AAC+DOLBY EX",
+        "AAC+DSUR",
+        "AAC+NEURAL:X",
+        "AAC+PL2Z H",
         "DOLBY ATMOS",
         "DOLBY AUDIO - DD + DSUR",
         "DOLBY AUDIO - DD + NEURAL:X",
         "DOLBY AUDIO - DD+   + DSUR",
         "DOLBY AUDIO - DD+   + NEURAL:X",
-        "DOLBY AUDIO - DOLBY DIGITAL PLUS",
         "DOLBY AUDIO - DOLBY DIGITAL",
+        "DOLBY AUDIO - DOLBY DIGITAL PLUS",
         "DOLBY AUDIO - DOLBY SURROUND",
         "DOLBY AUDIO - DOLBY TRUEHD",
         "DOLBY AUDIO - TRUEHD + DSUR",
         "DOLBY AUDIO - TRUEHD + NEURAL:X",
         "DOLBY AUDIO-DD",
+        "DOLBY AUDIO-DD+",
         "DOLBY AUDIO-DD+ +DSUR",
-        # Added both variants as we don't know if type is intentional
+        # FY24 specification uses incorrect spelling
         "DOLBY AUDIO-DD+ +NERUAL:X",
+        # FY23 specification uses correct spelling, go figure
         "DOLBY AUDIO-DD+ +NEURAL:X",
-        "DOLBY AUDIO-DD+",
-        "DOLBY AUDIO-DD+",
         "DOLBY AUDIO-DD+DSUR",
         "DOLBY AUDIO-DD+NEURAL:X",
         "DOLBY AUDIO-DSUR",
@@ -398,18 +481,31 @@ SOUND_MODE_MAPPING = {
         "DOLBY D + +DOLBY SURROUND",
         "DOLBY D + DOLBY SURROUND",
         "DOLBY D + NEURAL:X",
-        "DOLBY D+ +DS",
+        "DOLBY D EX",
         "DOLBY D+",
+        "DOLBY D+ +DS",
+        "DOLBY D+ +EX",
+        "DOLBY D+ +PL2Z H",
         "DOLBY D+DS",
+        "DOLBY D+PL2Z H",
+        "DOLBY DIGITAL",
+        "DOLBY DIGITAL +",
         "DOLBY DIGITAL + + NEURAL:X",
         "DOLBY DIGITAL + NEURAL:X",
-        "DOLBY DIGITAL +",
-        "DOLBY DIGITAL",
-        "DOLBY HD + DOLBY SURROUND",
         "DOLBY HD",
+        "DOLBY HD + DOLBY SURROUND",
+        "DOLBY HD+EX",
+        "DOLBY HD+PL2Z H",
+        "DOLBY PL2Z H",
         "DOLBY PRO LOGIC",
         "DOLBY SURROUND",
         "DOLBY TRUEHD",
+        "M CH IN+DOLBY EX",
+        "M CH IN+DSUR",
+        "M CH IN+PL2Z H",
+        "MPEG-H",
+        "MPEG2 AAC",
+        "MPEG4 AAC",
         "MULTI IN + DOLBY SURROUND",
         "MULTI IN + DSUR",
         "MULTI IN + NEURAL:X",
@@ -417,37 +513,58 @@ SOUND_MODE_MAPPING = {
         "STANDARD(DOLBY)",
     ],
     "DTS SURROUND": [
+        "AAC+NEURAL:X",
+        "AAC+VIRTUAL:X",
         "DTS + DOLBY SURROUND",
         "DTS + NEURAL:X",
         "DTS + VIRTUAL:X",
-        "DTS HD MSTR",
+        "DTS ES 8CH DSCRT",
+        "DTS ES DSCRT+NEURAL:X",
+        "DTS ES DSCRT6.1",
+        "DTS ES MTRX+NEURAL:X",
+        "DTS ES MTRX6.1",
+        "DTS EXPRESS",
         "DTS HD",
+        "DTS HD MSTR",
         "DTS HD+DSUR",
+        "DTS HD+NEO:6",
         "DTS HD+NEURAL:X",
+        "DTS HD+PL2Z H",
         "DTS HD+VIRTUAL:X",
         "DTS NEURAL:X",
         "DTS SURROUND",
         "DTS VIRTUAL:X",
+        "DTS-HD",
         "DTS-HD + DOLBY SURROUND",
         "DTS-HD + DSUR",
         "DTS-HD + NEURAL:X",
         "DTS-HD MSTR",
-        "DTS-HD",
-        "DTS:X MSTR",
         "DTS:X",
+        "DTS:X MSTR",
         "DTS:X+VIRTUAL:X",
         "DTS+DSUR",
+        "DTS+NEO:6",
+        "DTS+NEUR",
         "DTS+NEURAL:X",
+        "DTS+PL2Z H",
+        "DTS+VIRTU",
         "DTS+VIRTUAL:X",
+        "DTS96 ES MTRX",
+        "DTS96/24",
+        "IMAX DTS",
         "IMAX DTS:X",
         "IMAX DTS:X+VIRTUAL:X",
-        "IMAX DTS",
         "IMAX DTS+NEURAL:X",
-        "M CH IN+DSUR",
+        "IMAX DTS+VIRTUAL:X",
         "M CH IN+NEURAL:X",
         "M CH IN+VIRTUAL:X",
         "MAX DTS+VIRTUAL:X",
+        # Exists in both DOLBY and DTS in the specification,
+        # but can't be in both here, so we it them in DTS only
         "MULTI CH IN",
+        # Exists in both DOLBY and DTS in the specification,
+        # but can't be in both here, so we it them in DTS only
+        "MULTI CH IN 7.1",
         "NEURAL:X",
         "STANDARD(DTS)",
         "VIRTUAL:X",
@@ -456,7 +573,6 @@ SOUND_MODE_MAPPING = {
     "AURO2DSURR": ["AURO-2D SURROUND", "AURO2DSURR"],
     "MCH STEREO": [
         "MCH STEREO",
-        "MULTI CH IN 7.1",
         "MULTI CH STEREO",
         "MULTI_CH_STEREO",
     ],
@@ -498,6 +614,7 @@ HDTUNERSTATUS_URL = "/goform/formTuner_HdXml.xml"
 COMMAND_NETAUDIO_POST_URL = "/NetAudio/index.put.asp"
 COMMAND_PAUSE = "/goform/formiPhoneAppDirect.xml?NS9B"
 COMMAND_PLAY = "/goform/formiPhoneAppDirect.xml?NS9A"
+COMMAND_STOP = "/goform/formiPhoneAppDirect.xml?NS9C"
 COMMAND_ECO_MODE = "/goform/formiPhoneAppDirect.xml?ECO{mode}"
 
 
@@ -554,7 +671,7 @@ COMMAND_AUROMATIC_3D_STRENGTH = "/goform/formiPhoneAppDirect.xml?PSAUROST%20{val
 COMMAND_AURO_3D_MODE = "/goform/formiPhoneAppDirect.xml?PSAUROMODEM%20{mode}"
 COMMAND_DIRAC_FILTER = "/goform/formiPhoneAppDirect.xml?PSDIRAC%20{filter}"
 COMMAND_LFC = "/goform/formiPhoneAppDirect.xml?PSLFC%20{mode}"
-COMMAND_CONTAMINATION_AMOUNT = "/goform/formiPhoneAppDirect.xml?PSCNTAMT%20{value}"
+COMMAND_CONTAINMENT_AMOUNT = "/goform/formiPhoneAppDirect.xml?PSCNTAMT%20{value}"
 COMMAND_LOUDNESS_MANAGEMENT = "/goform/formiPhoneAppDirect.xml?PSLOM%20{mode}"
 COMMAND_BASS_SYNC = "/goform/formiPhoneAppDirect.xml?PSBSC%20{mode}"
 COMMAND_DIALOG_ENHANCER = "/goform/formiPhoneAppDirect.xml?PSDEH%20{level}"
@@ -598,6 +715,22 @@ COMMAND_ILLUMINATION = "/goform/formiPhoneAppDirect.xml?ILB%20{mode}"  # Marantz
 COMMAND_AUTO_LIP_SYNC = (
     "/goform/formiPhoneAppDirect.xml?SSHOSALS%20{mode}"  # Marantz Only
 )
+COMMAND_DOLBY_ATMOS_TOGGLE_DENON = "/goform/formiPhoneAppDirect.xml?RCKSK0410348"
+COMMAND_DOLBY_ATMOS_TOGGLE_MARANTZ = "/goform/formiPhoneAppDirect.xml?RCRC51606425"
+COMMAND_PAGE_UP_DENON = "/goform/formiPhoneAppDirect.xml?RCKSK0410945"
+COMMAND_PAGE_DOWN_DENON = "/goform/formiPhoneAppDirect.xml?RCKSK0410946"
+COMMAND_PAGE_UP_MARANTZ = "/goform/formiPhoneAppDirect.xml?RCRC52708105"
+COMMAND_PAGE_DOWN_MARANTZ = "/goform/formiPhoneAppDirect.xml?RCRC52708005"
+COMMAND_INPUT_MODE_SELECT_DENON = "/goform/formiPhoneAppDirect.xml?RCKSK0410352"
+COMMAND_INPUT_MODE_AUTO_DENON = "/goform/formiPhoneAppDirect.xml?RCKSK0410358"
+COMMAND_INPUT_MODE_HDMI_DENON = "/goform/formiPhoneAppDirect.xml?RCKSK0410357"
+COMMAND_INPUT_MODE_DIGITAL_DENON = "/goform/formiPhoneAppDirect.xml?RCKSK0410359"
+COMMAND_INPUT_MODE_ANALOG_DENON = "/goform/formiPhoneAppDirect.xml?RCKSK0410353"
+COMMAND_INPUT_MODE_SELECT_MARANTZ = "/goform/formiPhoneAppDirect.xml?RCRC51600101"
+COMMAND_INPUT_MODE_AUTO_MARANTZ = "/goform/formiPhoneAppDirect.xml?RCRC51600115"
+COMMAND_INPUT_MODE_HDMI_MARANTZ = "/goform/formiPhoneAppDirect.xml?RCRC51600116"
+COMMAND_INPUT_MODE_DIGITAL_MARANTZ = "/goform/formiPhoneAppDirect.xml?RCRC51600117"
+COMMAND_INPUT_MODE_ANALOG_MARANTZ = "/goform/formiPhoneAppDirect.xml?RCRC51600118"
 
 # Zone 2 URLs
 STATUS_Z2_URL = "/goform/formZone2_Zone2XmlStatus.xml"
@@ -644,7 +777,7 @@ DENONAVR_URLS = ReceiverURLs(
     command_sel_sound_mode=COMMAND_SEL_SM_URL,
     command_neural_x_on_off=COMMAND_NEURAL_X_ON_OFF,
     command_imax_auto_off=COMMAND_IMAX_AUTO_OFF,
-    command_imax_audio_settings=COMMAND_IMAX_AUTO_OFF,
+    command_imax_audio_settings=COMMAND_IMAX_AUDIO_SETTINGS,
     command_imax_hpf=COMMAND_IMAX_HPF,
     command_imax_lpf=COMMAND_IMAX_LPF,
     command_imax_subwoofer_mode=COMMAND_IMAX_SUBWOOFER_MODE,
@@ -654,6 +787,7 @@ DENONAVR_URLS = ReceiverURLs(
     command_set_all_zone_stereo=COMMAND_SET_ZST_URL,
     command_pause=COMMAND_PAUSE,
     command_play=COMMAND_PLAY,
+    command_stop=COMMAND_STOP,
     command_cusor_up=COMMAND_CURSOR_UP,
     command_cusor_down=COMMAND_CURSOR_DOWN,
     command_cusor_left=COMMAND_CURSOR_LEFT,
@@ -684,14 +818,14 @@ DENONAVR_URLS = ReceiverURLs(
     command_dirac_filter=COMMAND_DIRAC_FILTER,
     command_eco_mode=COMMAND_ECO_MODE,
     command_lfc=COMMAND_LFC,
-    command_containment_amount=COMMAND_CONTAMINATION_AMOUNT,
+    command_containment_amount=COMMAND_CONTAINMENT_AMOUNT,
     command_loudness_management=COMMAND_LOUDNESS_MANAGEMENT,
     command_bass_sync=COMMAND_BASS_SYNC,
     command_dialog_enhancer=COMMAND_DIALOG_ENHANCER,
     command_hdmi_output=COMMAND_HDMI_OUTPUT,
     command_hdmi_audio_decode=COMMAND_HDMI_AUDIO_DECODE,
     command_quick_select_mode=COMMAND_QUICK_SELECT_MODE,
-    command_quick_select_memory=COMMAND_QUICK_SELECT_MODE,
+    command_quick_select_memory=COMMAND_QUICK_SELECT_MEMORY,
     command_smart_select_mode=COMMAND_SMART_SELECT_MODE,  # Marantz
     command_smart_select_memory=COMMAND_SMART_SELECT_MEMORY,  # Marantz
     command_auto_standby=COMMAND_AUTO_STANDBY,
@@ -724,6 +858,22 @@ DENONAVR_URLS = ReceiverURLs(
     command_dac_filter=COMMAND_DAC_FILTER,  # Marantz Only
     command_illumination=COMMAND_ILLUMINATION,  # Marantz Only
     command_auto_lip_sync=COMMAND_AUTO_LIP_SYNC,  # Marantz Only
+    command_dolby_atmos_toggle_denon=COMMAND_DOLBY_ATMOS_TOGGLE_DENON,
+    command_dolby_atmos_toggle_marantz=COMMAND_DOLBY_ATMOS_TOGGLE_MARANTZ,
+    command_page_up_denon=COMMAND_PAGE_UP_DENON,
+    command_page_down_denon=COMMAND_PAGE_DOWN_DENON,
+    command_page_up_marantz=COMMAND_PAGE_UP_MARANTZ,
+    command_page_down_marantz=COMMAND_PAGE_DOWN_MARANTZ,
+    command_input_mode_select_denon=COMMAND_INPUT_MODE_SELECT_DENON,
+    command_input_mode_auto_denon=COMMAND_INPUT_MODE_AUTO_DENON,
+    command_input_mode_hdmi_denon=COMMAND_INPUT_MODE_HDMI_DENON,
+    command_input_mode_digital_denon=COMMAND_INPUT_MODE_DIGITAL_DENON,
+    command_input_mode_analog_denon=COMMAND_INPUT_MODE_ANALOG_DENON,
+    command_input_mode_select_marantz=COMMAND_INPUT_MODE_SELECT_MARANTZ,
+    command_input_mode_auto_marantz=COMMAND_INPUT_MODE_AUTO_MARANTZ,
+    command_input_mode_hdmi_marantz=COMMAND_INPUT_MODE_HDMI_MARANTZ,
+    command_input_mode_digital_marantz=COMMAND_INPUT_MODE_DIGITAL_MARANTZ,
+    command_input_mode_analog_marantz=COMMAND_INPUT_MODE_ANALOG_MARANTZ,
 )
 
 ZONE2_URLS = ReceiverURLs(
@@ -757,6 +907,7 @@ ZONE2_URLS = ReceiverURLs(
     command_set_all_zone_stereo=COMMAND_SET_ZST_URL,
     command_pause=COMMAND_PAUSE,
     command_play=COMMAND_PLAY,
+    command_stop=COMMAND_STOP,
     command_cusor_up=COMMAND_CURSOR_UP,
     command_cusor_down=COMMAND_CURSOR_DOWN,
     command_cusor_left=COMMAND_CURSOR_LEFT,
@@ -787,7 +938,7 @@ ZONE2_URLS = ReceiverURLs(
     command_dirac_filter=COMMAND_DIRAC_FILTER,
     command_eco_mode=COMMAND_ECO_MODE,
     command_lfc=COMMAND_LFC,
-    command_containment_amount=COMMAND_CONTAMINATION_AMOUNT,
+    command_containment_amount=COMMAND_CONTAINMENT_AMOUNT,
     command_loudness_management=COMMAND_LOUDNESS_MANAGEMENT,
     command_bass_sync=COMMAND_BASS_SYNC,
     command_dialog_enhancer=COMMAND_DIALOG_ENHANCER,
@@ -827,6 +978,22 @@ ZONE2_URLS = ReceiverURLs(
     command_dac_filter=COMMAND_DAC_FILTER,  # Marantz Only
     command_illumination=COMMAND_ILLUMINATION,  # Marantz Only
     command_auto_lip_sync=COMMAND_AUTO_LIP_SYNC,  # Marantz Only
+    command_dolby_atmos_toggle_denon=COMMAND_DOLBY_ATMOS_TOGGLE_DENON,
+    command_dolby_atmos_toggle_marantz=COMMAND_DOLBY_ATMOS_TOGGLE_MARANTZ,
+    command_page_up_denon=COMMAND_PAGE_UP_DENON,
+    command_page_down_denon=COMMAND_PAGE_DOWN_DENON,
+    command_page_up_marantz=COMMAND_PAGE_UP_MARANTZ,
+    command_page_down_marantz=COMMAND_PAGE_DOWN_MARANTZ,
+    command_input_mode_select_denon=COMMAND_INPUT_MODE_SELECT_DENON,
+    command_input_mode_auto_denon=COMMAND_INPUT_MODE_AUTO_DENON,
+    command_input_mode_hdmi_denon=COMMAND_INPUT_MODE_HDMI_DENON,
+    command_input_mode_digital_denon=COMMAND_INPUT_MODE_DIGITAL_DENON,
+    command_input_mode_analog_denon=COMMAND_INPUT_MODE_ANALOG_DENON,
+    command_input_mode_select_marantz=COMMAND_INPUT_MODE_SELECT_MARANTZ,
+    command_input_mode_auto_marantz=COMMAND_INPUT_MODE_AUTO_MARANTZ,
+    command_input_mode_hdmi_marantz=COMMAND_INPUT_MODE_HDMI_MARANTZ,
+    command_input_mode_digital_marantz=COMMAND_INPUT_MODE_DIGITAL_MARANTZ,
+    command_input_mode_analog_marantz=COMMAND_INPUT_MODE_ANALOG_MARANTZ,
 )
 
 ZONE3_URLS = ReceiverURLs(
@@ -860,6 +1027,7 @@ ZONE3_URLS = ReceiverURLs(
     command_set_all_zone_stereo=COMMAND_SET_ZST_URL,
     command_pause=COMMAND_PAUSE,
     command_play=COMMAND_PLAY,
+    command_stop=COMMAND_STOP,
     command_cusor_up=COMMAND_CURSOR_UP,
     command_cusor_down=COMMAND_CURSOR_DOWN,
     command_cusor_left=COMMAND_CURSOR_LEFT,
@@ -890,7 +1058,7 @@ ZONE3_URLS = ReceiverURLs(
     command_dirac_filter=COMMAND_DIRAC_FILTER,
     command_eco_mode=COMMAND_ECO_MODE,
     command_lfc=COMMAND_LFC,
-    command_containment_amount=COMMAND_CONTAMINATION_AMOUNT,
+    command_containment_amount=COMMAND_CONTAINMENT_AMOUNT,
     command_loudness_management=COMMAND_LOUDNESS_MANAGEMENT,
     command_bass_sync=COMMAND_BASS_SYNC,
     command_dialog_enhancer=COMMAND_DIALOG_ENHANCER,
@@ -930,6 +1098,22 @@ ZONE3_URLS = ReceiverURLs(
     command_dac_filter=COMMAND_DAC_FILTER,  # Marantz Only
     command_illumination=COMMAND_ILLUMINATION,  # Marantz Only
     command_auto_lip_sync=COMMAND_AUTO_LIP_SYNC,  # Marantz Only
+    command_dolby_atmos_toggle_denon=COMMAND_DOLBY_ATMOS_TOGGLE_DENON,
+    command_dolby_atmos_toggle_marantz=COMMAND_DOLBY_ATMOS_TOGGLE_MARANTZ,
+    command_page_up_denon=COMMAND_PAGE_UP_DENON,
+    command_page_down_denon=COMMAND_PAGE_DOWN_DENON,
+    command_page_up_marantz=COMMAND_PAGE_UP_MARANTZ,
+    command_page_down_marantz=COMMAND_PAGE_DOWN_MARANTZ,
+    command_input_mode_select_denon=COMMAND_INPUT_MODE_SELECT_DENON,
+    command_input_mode_auto_denon=COMMAND_INPUT_MODE_AUTO_DENON,
+    command_input_mode_hdmi_denon=COMMAND_INPUT_MODE_HDMI_DENON,
+    command_input_mode_digital_denon=COMMAND_INPUT_MODE_DIGITAL_DENON,
+    command_input_mode_analog_denon=COMMAND_INPUT_MODE_ANALOG_DENON,
+    command_input_mode_select_marantz=COMMAND_INPUT_MODE_SELECT_MARANTZ,
+    command_input_mode_auto_marantz=COMMAND_INPUT_MODE_AUTO_MARANTZ,
+    command_input_mode_hdmi_marantz=COMMAND_INPUT_MODE_HDMI_MARANTZ,
+    command_input_mode_digital_marantz=COMMAND_INPUT_MODE_DIGITAL_MARANTZ,
+    command_input_mode_analog_marantz=COMMAND_INPUT_MODE_ANALOG_MARANTZ,
 )
 
 # Telnet Events
@@ -941,7 +1125,6 @@ TELNET_EVENTS = {
     "DIM",
     "ECO",
     "HD",
-    "ILB",  # Marantz Only
     "MN",
     "MS",
     "MU",
@@ -976,6 +1159,7 @@ TELNET_EVENTS = {
 ALL_ZONE_TELNET_EVENTS = {
     "DIM",
     "HD",
+    "ILB",  # Marantz Only
     "NS",
     "NSA",
     "NSE",
@@ -1012,6 +1196,7 @@ DENONAVR_TELNET_COMMANDS = TelnetCommands(
     command_set_all_zone_stereo="MN",
     command_pause="NS9B",
     command_play="NS9A",
+    command_stop="NS9C",
     command_multieq="PSMULTEQ:",
     command_dynamiceq="PSDYNEQ ",
     command_reflevoffset="PSREFLEV ",
@@ -1089,6 +1274,22 @@ DENONAVR_TELNET_COMMANDS = TelnetCommands(
     command_dac_filter="PSDACFIL {mode}",  # Marantz Only
     command_illumination="ILB {mode}",  # Marantz Only
     command_auto_lip_sync="SSHOSALS {mode}",  # Marantz Only
+    command_dolby_atmos_toggle_denon="RCKSK0410348",
+    command_dolby_atmos_toggle_marantz="RCRC51606425",
+    command_page_up_denon="RCKSK0410945",
+    command_page_down_denon="RCKSK0410946",
+    command_page_up_marantz="RCRC52708105",
+    command_page_down_marantz="RCRC52708005",
+    command_input_mode_select_denon="RCKSK0410352",
+    command_input_mode_auto_denon="RCKSK0410358",
+    command_input_mode_hdmi_denon="RCKSK0410357",
+    command_input_mode_digital_denon="RCKSK0410359",
+    command_input_mode_analog_denon="RCKSK0410353",
+    command_input_mode_select_marantz="RCRC51600101",
+    command_input_mode_auto_marantz="RCRC51600115",
+    command_input_mode_hdmi_marantz="RCRC51600116",
+    command_input_mode_digital_marantz="RCRC51600117",
+    command_input_mode_analog_marantz="RCRC51600118",
 )
 
 ZONE2_TELNET_COMMANDS = TelnetCommands(
@@ -1113,6 +1314,7 @@ ZONE2_TELNET_COMMANDS = TelnetCommands(
     command_set_all_zone_stereo="MN",
     command_pause="NS9B",
     command_play="NS9A",
+    command_stop="NS9C",
     command_multieq="PSMULTEQ:",
     command_dynamiceq="PSDYNEQ ",
     command_reflevoffset="PSREFLEV ",
@@ -1190,6 +1392,22 @@ ZONE2_TELNET_COMMANDS = TelnetCommands(
     command_dac_filter="PSDACFIL {mode}",  # Marantz Only
     command_illumination="ILB {mode}",  # Marantz Only
     command_auto_lip_sync="SSHOSALS {mode}",  # Marantz Only
+    command_dolby_atmos_toggle_denon="RCKSK0410348",
+    command_dolby_atmos_toggle_marantz="RCRC51606425",
+    command_page_up_denon="RCKSK0410945",
+    command_page_down_denon="RCKSK0410946",
+    command_page_up_marantz="RCRC52708105",
+    command_page_down_marantz="RCRC52708005",
+    command_input_mode_select_denon="RCKSK0410352",
+    command_input_mode_auto_denon="RCKSK0410358",
+    command_input_mode_hdmi_denon="RCKSK0410357",
+    command_input_mode_digital_denon="RCKSK0410359",
+    command_input_mode_analog_denon="RCKSK0410353",
+    command_input_mode_select_marantz="RCRC51600101",
+    command_input_mode_auto_marantz="RCRC51600115",
+    command_input_mode_hdmi_marantz="RCRC51600116",
+    command_input_mode_digital_marantz="RCRC51600117",
+    command_input_mode_analog_marantz="RCRC51600118",
 )
 
 ZONE3_TELNET_COMMANDS = TelnetCommands(
@@ -1214,6 +1432,7 @@ ZONE3_TELNET_COMMANDS = TelnetCommands(
     command_set_all_zone_stereo="MN",
     command_pause="NS9B",
     command_play="NS9A",
+    command_stop="NS9C",
     command_multieq="PSMULTEQ:",
     command_dynamiceq="PSDYNEQ ",
     command_reflevoffset="PSREFLEV ",
@@ -1291,6 +1510,22 @@ ZONE3_TELNET_COMMANDS = TelnetCommands(
     command_dac_filter="PSDACFIL {mode}",  # Marantz Only
     command_illumination="ILB {mode}",  # Marantz Only
     command_auto_lip_sync="SSHOSALS {mode}",  # Marantz Only
+    command_dolby_atmos_toggle_denon="RCKSK0410348",
+    command_dolby_atmos_toggle_marantz="RCRC51606425",
+    command_page_up_denon="RCKSK0410945",
+    command_page_down_denon="RCKSK0410946",
+    command_page_up_marantz="RCRC52708105",
+    command_page_down_marantz="RCRC52708005",
+    command_input_mode_select_denon="RCKSK0410352",
+    command_input_mode_auto_denon="RCKSK0410358",
+    command_input_mode_hdmi_denon="RCKSK0410357",
+    command_input_mode_digital_denon="RCKSK0410359",
+    command_input_mode_analog_denon="RCKSK0410353",
+    command_input_mode_select_marantz="RCRC51600101",
+    command_input_mode_auto_marantz="RCRC51600115",
+    command_input_mode_hdmi_marantz="RCRC51600116",
+    command_input_mode_digital_marantz="RCRC51600117",
+    command_input_mode_analog_marantz="RCRC51600118",
 )
 
 # States
@@ -1302,6 +1537,7 @@ STATE_ON = "on"
 STATE_OFF = "off"
 STATE_PLAYING = "playing"
 STATE_PAUSED = "paused"
+STATE_STOPPED = "stopped"
 SETTINGS_MENU_ON = "ON"
 SETTINGS_MENU_OFF = "OFF"
 SETTINGS_MENU_STATES = {SETTINGS_MENU_ON, SETTINGS_MENU_OFF}
@@ -1310,6 +1546,7 @@ DIMER_DIM = "DIM"
 DIMER_DARK = "DAR"
 DIMER_OFF = "OFF"
 DIMMER_STATES = {DIMER_BRIGHT, DIMER_DIM, DIMER_DARK, DIMER_OFF}
+NETAUDIO_PLAYING = "Now Playing"
 
 # Zones
 ALL_ZONES = "All"
@@ -1328,7 +1565,12 @@ ZONE2_ZONE3_NAME = {ZONE2: None, ZONE3: None}
 APPCOMMAND_CMD_TEXT = "cmd_text"
 APPCOMMAND_NAME = "name"
 
-# Audyssey parameter
+# _MAP dictionaries map receiver outputs to denonavr properties
+# _MAP_REVERSE dictionaries map them the opposite way
+
+MultiEQModes = Literal["Off", "Flat", "L/R Bypass", "Reference", "Manual"]
+"""Multi EQ modes."""
+
 MULTI_EQ_MAP_APPCOMMAND = {"0": "Off", "1": "Flat", "2": "L/R Bypass", "3": "Reference"}
 MULTI_EQ_MAP_TELNET = {
     "OFF": "Off",
@@ -1338,21 +1580,27 @@ MULTI_EQ_MAP_TELNET = {
     "MANUAL": "Manual",
 }
 MULTI_EQ_MAP = {**MULTI_EQ_MAP_APPCOMMAND, **MULTI_EQ_MAP_TELNET}
-MULTI_EQ_MAP_LABELS_APPCOMMAND = {
+MULTI_EQ_MAP_REVERSE_APPCOMMAND = {
     value: key for key, value in MULTI_EQ_MAP_APPCOMMAND.items()
 }
-MULTI_EQ_MAP_LABELS_TELNET = {value: key for key, value in MULTI_EQ_MAP_TELNET.items()}
+MULTI_EQ_MAP_REVERSE_TELNET = {value: key for key, value in MULTI_EQ_MAP_TELNET.items()}
+
+ReferenceLevelOffsets = Literal["0dB", "+5dB", "+10dB", "+15dB"]
+"""Reference Level Offsets."""
 
 REF_LVL_OFFSET_MAP_APPCOMMAND = {"0": "0dB", "1": "+5dB", "2": "+10dB", "3": "+15dB"}
 REF_LVL_OFFSET_MAP_TELNET = {"0": "0dB", "5": "+5dB", "10": "+10dB", "15": "+15dB"}
 REF_LVL_OFFSET_MAP = {**REF_LVL_OFFSET_MAP_APPCOMMAND, **REF_LVL_OFFSET_MAP_TELNET}
-REF_LVL_OFFSET_MAP_LABELS_APPCOMMAND = {
+REF_LVL_OFFSET_MAP_REVERSE_APPCOMMAND = {
     value: key for key, value in REF_LVL_OFFSET_MAP_APPCOMMAND.items()
 }
-REF_LVL_OFFSET_MAP_LABELS_TELNET = {
+REF_LVL_OFFSET_MAP_REVERSE_TELNET = {
     value: key for key, value in REF_LVL_OFFSET_MAP_TELNET.items()
 }
 
+DynamicVolumeSettings = Literal["Off", "Light", "Medium", "Heavy"]
+"""Dynamic Volume Settings."""
+
 DYNAMIC_VOLUME_MAP_APPCOMMAND = {"0": "Off", "1": "Light", "2": "Medium", "3": "Heavy"}
 DYNAMIC_VOLUME_MAP_TELNET = {
     "OFF": "Off",
@@ -1361,10 +1609,10 @@ DYNAMIC_VOLUME_MAP_TELNET = {
     "HEV": "Heavy",
 }
 DYNAMIC_VOLUME_MAP = {**DYNAMIC_VOLUME_MAP_APPCOMMAND, **DYNAMIC_VOLUME_MAP_TELNET}
-DYNAMIC_VOLUME_MAP_LABELS_APPCOMMAND = {
+DYNAMIC_VOLUME_MAP_REVERSE_APPCOMMAND = {
     value: key for key, value in DYNAMIC_VOLUME_MAP_APPCOMMAND.items()
 }
-DYNAMIC_VOLUME_MAP_LABELS_TELNET = {
+DYNAMIC_VOLUME_MAP_REVERSE_TELNET = {
     value: key for key, value in DYNAMIC_VOLUME_MAP_TELNET.items()
 }
 
@@ -1372,12 +1620,12 @@ AudioRestorers = Literal["Off", "Low", "Medium", "High"]
 """Audio Restorer settings."""
 
 AUDIO_RESTORER_MAP = {
-    "Off": "OFF",
-    "Low": "LOW",
-    "Medium": "MED",
-    "High": "HI",
+    "OFF": "Off",
+    "LOW": "Low",
+    "MED": "Medium",
+    "HI": "High",
 }
-AUDIO_RESTORER_MAP_LABELS = {value: key for key, value in AUDIO_RESTORER_MAP.items()}
+AUDIO_RESTORER_MAP_REVERSE = {value: key for key, value in AUDIO_RESTORER_MAP.items()}
 
 AuroMatic3DPresets = Literal[
     "Small",
@@ -1389,58 +1637,93 @@ AuroMatic3DPresets = Literal[
 """Auro-Matic 3D Presets."""
 
 AURO_MATIC_3D_PRESET_MAP = {
-    "Small": "SMA",
-    "Medium": "MED",
-    "Large": "LAR",
-    "Speech": "SPE",
-    "Movie": "MOV",
+    "SMA": "Small",
+    "MED": "Medium",
+    "LAR": "Large",
+    "SPE": "Speech",
+    "MOV": "Movie",
 }
-AURO_MATIC_3D_PRESET_MAP_LABELS = {
+AURO_MATIC_3D_PRESET_MAP_REVERSE = {
     value: key for key, value in AURO_MATIC_3D_PRESET_MAP.items()
 }
 
 Auro3DModes = Literal["Direct", "Channel Expansion"]
 """Auro 3D Modes."""
 
-AURO_3D_MODE_MAP = {"Direct": "DRCT", "Channel Expansion": "EXP"}
-AURO_3D_MODE_MAP_MAP_LABELS = {value: key for key, value in AURO_3D_MODE_MAP.items()}
+AURO_3D_MODE_MAP = {"DRCT": "Direct", "EXP": "Channel Expansion"}
+AURO_3D_MODE_MAP_REVERSE = {value: key for key, value in AURO_3D_MODE_MAP.items()}
 
-AutoStandbys = Literal["OFF", "15M", "30M", "60M"]
+AutoStandbys = Literal["OFF", "15M", "30M", "60M", "2H", "4H", "8H"]
+
+AUTO_STANDBY_MAP_APPCOMMAND = {
+    "0": "OFF",
+    "15": "15M",
+    "30": "30M",
+    "60": "60M",
+    "120": "2H",
+    "240": "4H",
+    "480": "8H",
+}
+AUTO_STANDBY_MAP_TELNET = {
+    "OFF": "OFF",
+    "15M": "15M",
+    "30M": "30M",
+    "60M": "60M",
+    "2H": "2H",
+    "4H": "4H",
+    "8H": "8H",
+}
+AUTO_STANDBY_MAP = {**AUTO_STANDBY_MAP_APPCOMMAND, **AUTO_STANDBY_MAP_TELNET}
 
 BluetoothOutputModes = Literal["Bluetooth + Speakers", "Bluetooth Only"]
 """Bluetooth Output Modes."""
 
 BLUETOOTH_OUTPUT_MODES_MAP = {
-    "Bluetooth + Speakers": "SP",
-    "Bluetooth Only": "BT",
+    "SP": "Bluetooth + Speakers",
+    "BT": "Bluetooth Only",
 }
-BLUETOOTH_OUTPUT_MAP_LABELS = {
+BLUETOOTH_OUTPUT_MODES_MAP_REVERSE = {
     value: key for key, value in BLUETOOTH_OUTPUT_MODES_MAP.items()
 }
 
-DIMMER_MODE_MAP = {
-    "Off": DIMER_OFF,
-    "Dark": DIMER_DARK,
-    "Dim": DIMER_DIM,
-    "Bright": DIMER_BRIGHT,
+DIMMER_MODE_MAP_APPCOMMAND = {
+    "0": "Off",
+    "1": "Dark",
+    "2": "Dim",
+    "3": "Bright",
 }
-DIMMER_MODE_MAP_LABELS = {value: key for key, value in DIMMER_MODE_MAP.items()}
+DIMMER_MODE_MAP_TELNET = {
+    DIMER_OFF: "Off",
+    DIMER_DARK: "Dark",
+    DIMER_DIM: "Dim",
+    DIMER_BRIGHT: "Bright",
+}
+DIMMER_MODE_MAP = {**DIMMER_MODE_MAP_TELNET, **DIMMER_MODE_MAP_APPCOMMAND}
+# Telnet literals are correct for telnet and HTTP setters
+DIMMER_MODE_MAP_REVERSE = {value: key for key, value in DIMMER_MODE_MAP_TELNET.items()}
 
 DimmerModes = Literal["Off", "Dark", "Dim", "Bright"]
 """Dimmer Modes."""
 
-DIRAC_FILTER_MAP = {"Off": "OFF", "Slot 1": "1", "Slot 2": "2", "Slot 3": "3"}
-DIRAC_FILTER_MAP_LABELS = {value: key for key, value in DIRAC_FILTER_MAP.items()}
+DIRAC_FILTER_MAP = {"OFF": "Off", "1": "Slot 1", "2": "Slot 2", "3": "Slot 3"}
+DIRAC_FILTER_MAP_REVERSE = {value: key for key, value in DIRAC_FILTER_MAP.items()}
 
 DiracFilters = Literal["Slot 1", "Slot 2", "Slot 3", "Off"]
 """Dirac Filters."""
 
-ECO_MODE_MAP = {
-    "On": "ON",
-    "Auto": "AUTO",
-    "Off": "OFF",
+ECO_MODE_MAP_APPCOMMAND = {
+    "0": "Off",
+    "1": "On",
+    "2": "Auto",
 }
-ECO_MODE_MAP_LABELS = {value: key for key, value in ECO_MODE_MAP.items()}
+ECO_MODE_MAP_TELNET = {
+    "ON": "On",
+    "AUTO": "Auto",
+    "OFF": "Off",
+}
+ECO_MODE_MAP = {**ECO_MODE_MAP_APPCOMMAND, **ECO_MODE_MAP_TELNET}
+# Telnet literals are correct for telnet and HTTP setters
+ECO_MODE_MAP_REVERSE = {value: key for key, value in ECO_MODE_MAP_TELNET.items()}
 
 EcoModes = Literal["On", "Auto", "Off"]
 """Eco Modes."""
@@ -1459,17 +1742,17 @@ EffectSpeakers = Literal[
 """Effect Speakers."""
 
 EFFECT_SPEAKER_SELECTION_MAP = {
-    "Floor": "FL",
-    "Front": "FR",
-    "Front Height": "FH",
-    "Front Wide": "FW",
-    "Front Height + Front Wide": "HW",
-    "Height + Floor": "HF",
-    "Surround Back": "SB",
-    "Surround Back + Front Height": "BH",
-    "Surround Back + Front Wide": "BW",
+    "FL": "Floor",
+    "FR": "Front",
+    "FH": "Front Height",
+    "FW": "Front Wide",
+    "HW": "Front Height + Front Wide",
+    "HF": "Height + Floor",
+    "SB": "Surround Back",
+    "BH": "Surround Back + Front Height",
+    "BW": "Surround Back + Front Wide",
 }
-EFFECT_SPEAKER_SELECTION_MAP_LABELS = {
+EFFECT_SPEAKER_SELECTION_MAP_REVERSE = {
     value: key for key, value in EFFECT_SPEAKER_SELECTION_MAP.items()
 }
 
@@ -1477,15 +1760,15 @@ DRCs = Literal["AUTO", "LOW", "MID", "HI", "OFF"]
 """Dynamic Range Control (DRC) Settings."""
 
 HDMI_OUTPUT_MAP = {
-    "Auto": "AUTO",
-    "HDMI1": "1",
-    "HDMI2": "2",
-}
-HDMI_OUTPUT_MAP_LABELS = {
     "MONIAUTO": "Auto",
     "MONI1": "HDMI1",
     "MONI2": "HDMI2",
 }
+HDMI_OUTPUT_MAP_REVERSE = {
+    "Auto": "AUTO",
+    "HDMI1": "1",
+    "HDMI2": "2",
+}
 
 HDMIOutputs = Literal["Auto", "HDMI1", "HDMI2"]
 """HDMI Output Modes."""
@@ -1496,56 +1779,55 @@ Subwoofers = Literal["Subwoofer", "Subwoofer 2", "Subwoofer 3", "Subwoofer 4"]
 """Subwoofers."""
 
 SUBWOOFERS_MAP = {
-    "Subwoofer": "",
-    "Subwoofer 2": "2",
-    "Subwoofer 3": "3",
-    "Subwoofer 4": "4",
-}
-"""Subwoofers."""
-
-SUBWOOFERS_MAP_LABELS = {
     "SWL": "Subwoofer",
     "SWL2": "Subwoofer 2",
     "SWL3": "Subwoofer 3",
     "SWL4": "Subwoofer 4",
 }
 
-CHANNEL_MAP = {
-    "Front Left": "FL",
-    "Front Right": "FR",
-    "Center": "C",
-    "Subwoofer": "SW",
-    "Subwoofer 2": "SW2",
-    "Subwoofer 3": "SW3",
-    "Subwoofer 4": "SW4",
-    "Surround Left": "SL",
-    "Surround Right": "SR",
-    "Surround Back Left": "SBL",
-    "Surround Back Right": "SBR",
-    "Front Height Left": "FHL",
-    "Front Height Right": "FHR",
-    "Front Wide Left": "FWL",
-    "Front Wide Right": "FWR",
-    "Top Front Left": "TFL",
-    "Top Front Right": "TFR",
-    "Top Middle Left": "TML",
-    "Top Middle Right": "TMR",
-    "Top Rear Left": "TRL",
-    "Top Rear Right": "TRR",
-    "Rear Height Left": "RHL",
-    "Rear Height Right": "RHR",
-    "Front Dolby Left": "FDL",
-    "Front Dolby Right": "FDR",
-    "Surround Dolby Left": "SDL",
-    "Surround Dolby Right": "SDR",
-    "Back Dolby Left": "BDL",
-    "Back Dolby Right": "BDR",
-    "Surround Height Left": "SHL",
-    "Surround Height Right": "SHR",
-    "Top Surround": "TS",
-    "Center Height": "CH",
+SUBWOOFERS_MAP_REVERSE = {
+    "Subwoofer": "",
+    "Subwoofer 2": "2",
+    "Subwoofer 3": "3",
+    "Subwoofer 4": "4",
 }
-CHANNEL_MAP_LABELS = {value: key for key, value in CHANNEL_MAP.items()}
+
+CHANNEL_MAP = {
+    "FL": "Front Left",
+    "FR": "Front Right",
+    "C": "Center",
+    "SW": "Subwoofer",
+    "SW2": "Subwoofer 2",
+    "SW3": "Subwoofer 3",
+    "SW4": "Subwoofer 4",
+    "SL": "Surround Left",
+    "SR": "Surround Right",
+    "SBL": "Surround Back Left",
+    "SBR": "Surround Back Right",
+    "FHL": "Front Height Left",
+    "FHR": "Front Height Right",
+    "FWL": "Front Wide Left",
+    "FWR": "Front Wide Right",
+    "TFL": "Top Front Left",
+    "TFR": "Top Front Right",
+    "TML": "Top Middle Left",
+    "TMR": "Top Middle Right",
+    "TRL": "Top Rear Left",
+    "TRR": "Top Rear Right",
+    "RHL": "Rear Height Left",
+    "RHR": "Rear Height Right",
+    "FDL": "Front Dolby Left",
+    "FDR": "Front Dolby Right",
+    "SDL": "Surround Dolby Left",
+    "SDR": "Surround Dolby Right",
+    "BDL": "Back Dolby Left",
+    "BDR": "Back Dolby Right",
+    "SHL": "Surround Height Left",
+    "SHR": "Surround Height Right",
+    "TS": "Top Surround",
+    "CH": "Center Height",
+}
+CHANNEL_MAP_REVERSE = {value: key for key, value in CHANNEL_MAP.items()}
 
 Channels = Literal[
     "Front Left",
@@ -1635,19 +1917,19 @@ CHANNEL_VOLUME_MAP = {
     "615": 11.5,
     "62": 12.0,
 }
-CHANNEL_VOLUME_MAP_LABELS = {value: key for key, value in CHANNEL_VOLUME_MAP.items()}
+CHANNEL_VOLUME_MAP_REVERSE = {value: key for key, value in CHANNEL_VOLUME_MAP.items()}
 
 DialogEnhancerLevels = Literal["Off", "Low", "Medium", "High"]
 """Dialog Enhancer Levels."""
 
 DIALOG_ENHANCER_LEVEL_MAP = {
-    "Off": "OFF",
-    "Low": "LOW",
-    "Medium": "MED",
-    "High": "HIGH",
+    "OFF": "Off",
+    "LOW": "Low",
+    "MED": "Medium",
+    "HIGH": "High",
 }
 
-DIALOG_ENHANCER_LEVEL_MAP_LABELS = {
+DIALOG_ENHANCER_LEVEL_MAP_REVERSE = {
     value: key for key, value in DIALOG_ENHANCER_LEVEL_MAP.items()
 }
 
@@ -1690,13 +1972,13 @@ VideoProcessingModes = Literal["Auto", "Game", "Movie", "Bypass"]
 """Video Processing Modes."""
 
 VIDEO_PROCESSING_MODES_MAP = {
-    "Auto": "AUTO",
-    "Game": "GAME",
-    "Movie": "MOVI",
-    "Bypass": "BYP",
+    "AUTO": "Auto",
+    "GAME": "Game",
+    "MOVI": "Movie",
+    "BYP": "Bypass",
 }
 
-VIDEO_PROCESSING_MODES_MAP_LABELS = {
+VIDEO_PROCESSING_MODES_MAP_REVERSE = {
     value: key for key, value in VIDEO_PROCESSING_MODES_MAP.items()
 }
 
@@ -1704,32 +1986,35 @@ MDAXs = Literal["Off", "Low", "Medium", "High"]
 """M-DAX Modes."""
 
 MDAX_MAP = {
-    "Off": "OFF",
-    "Low": "LOW",
-    "Medium": "MED",
-    "High": "HI",
+    "OFF": "Off",
+    "LOW": "Low",
+    "MED": "Medium",
+    "HI": "High",
 }
-MDAX_MAP_LABELS = {value: key for key, value in MDAX_MAP.items()}
+MDAX_MAP_REVERSE = {value: key for key, value in MDAX_MAP.items()}
 
 DACFilters = Literal["Mode 1", "Mode 2"]
 """DAC Filter Modes."""
 
 DAC_FILTERS_MAP = {
-    "Mode 1": "MODE1",
-    "Mode 2": "MODE2",
+    "MODE1": "Mode 1",
+    "MODE2": "Mode 2",
 }
 
-DAC_FILTERS_MAP_LABELS = {value: key for key, value in DAC_FILTERS_MAP.items()}
+DAC_FILTERS_MAP_REVERSE = {value: key for key, value in DAC_FILTERS_MAP.items()}
 
 Illuminations = Literal["Auto", "Bright", "Dim", "Dark", "Off"]
 """Illumination Modes."""
 
 ILLUMINATION_MAP = {
-    "Auto": "AUTO",
-    "Bright": "BRI",
-    "Dim": "DIM",
-    "Dark": "DAR",
-    "Off": "OFF",
+    "AUTO": "Auto",
+    "BRI": "Bright",
+    "DIM": "Dim",
+    "DAR": "Dark",
+    "OFF": "Off",
 }
 
-ILLUMINATION_MAP_LABELS = {value: key for key, value in ILLUMINATION_MAP.items()}
+ILLUMINATION_MAP_REVERSE = {value: key for key, value in ILLUMINATION_MAP.items()}
+
+InputModes = Literal["Select", "Auto", "HDMI", "Digital", "Analog"]
+"""Input Mode Selection."""
