@@ -16,14 +16,14 @@ import attr
 from .appcommand import AppCommands
 from .const import (
     CHANNEL_MAP,
-    CHANNEL_MAP_LABELS,
+    CHANNEL_MAP_REVERSE,
     CHANNEL_VOLUME_MAP,
-    CHANNEL_VOLUME_MAP_LABELS,
+    CHANNEL_VOLUME_MAP_REVERSE,
     DENON_ATTR_SETATTR,
     MAIN_ZONE,
     STATE_ON,
     SUBWOOFERS_MAP,
-    SUBWOOFERS_MAP_LABELS,
+    SUBWOOFERS_MAP_REVERSE,
     Channels,
     Subwoofers,
 )
@@ -119,7 +119,7 @@ class DenonAVRVolume(DenonAVRFoundation):
         channel_volume = parameter.split()
         if (
             len(channel_volume) != 2
-            or channel_volume[0] not in CHANNEL_MAP_LABELS
+            or channel_volume[0] not in CHANNEL_MAP
             or channel_volume[1] not in CHANNEL_VOLUME_MAP
         ):
             return
@@ -127,7 +127,7 @@ class DenonAVRVolume(DenonAVRFoundation):
         if self._channel_volumes is None:
             self._channel_volumes = {}
 
-        channel = CHANNEL_MAP_LABELS[channel_volume[0]]
+        channel = CHANNEL_MAP[channel_volume[0]]
         volume = channel_volume[1]
         self._channel_volumes[channel] = CHANNEL_VOLUME_MAP[volume]
 
@@ -142,16 +142,13 @@ class DenonAVRVolume(DenonAVRFoundation):
             return
 
         subwoofer_volume = parameter.split()
-        if (
-            len(subwoofer_volume) != 2
-            or subwoofer_volume[0] not in SUBWOOFERS_MAP_LABELS
-        ):
+        if len(subwoofer_volume) != 2 or subwoofer_volume[0] not in SUBWOOFERS_MAP:
             return
 
         if self._subwoofer_levels is None:
             self._subwoofer_levels = {}
 
-        subwoofer = SUBWOOFERS_MAP_LABELS[subwoofer_volume[0]]
+        subwoofer = SUBWOOFERS_MAP[subwoofer_volume[0]]
         level = subwoofer_volume[1]
         val = convert_on_off_bool(level)
         if val is not None:
@@ -306,7 +303,7 @@ class DenonAVRVolume(DenonAVRFoundation):
     # Setter #
     ##########
     async def async_volume_up(self) -> None:
-        """Volume up receiver via HTTP get command."""
+        """Volume up receiver."""
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_volume_up, skip_confirmation=True
@@ -317,7 +314,7 @@ class DenonAVRVolume(DenonAVRFoundation):
             )
 
     async def async_volume_down(self) -> None:
-        """Volume down receiver via HTTP get command."""
+        """Volume down receiver."""
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_volume_down, skip_confirmation=True
@@ -329,7 +326,7 @@ class DenonAVRVolume(DenonAVRFoundation):
 
     async def async_set_volume(self, volume: float) -> None:
         """
-        Set receiver volume via HTTP get command.
+        Set receiver volume.
 
         Volume is send in a format like -50.0.
         Minimum is -80.0, maximum at 18.0
@@ -351,7 +348,7 @@ class DenonAVRVolume(DenonAVRFoundation):
             )
 
     async def async_mute(self, mute: bool) -> None:
-        """Mute receiver via HTTP get command."""
+        """Mute receiver."""
         if mute:
             if self._device.telnet_available:
                 await self._device.telnet_api.async_send_commands(
@@ -372,10 +369,10 @@ class DenonAVRVolume(DenonAVRFoundation):
                 )
 
     async def async_channel_volume_up(self, channel: Channels) -> None:
-        """Increase Channel volume on receiver via HTTP get command."""
+        """Increase Channel volume on receiver."""
         self._is_valid_channel(channel)
 
-        mapped_channel = CHANNEL_MAP[channel]
+        mapped_channel = CHANNEL_MAP_REVERSE[channel]
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_channel_volume.format(
@@ -390,10 +387,10 @@ class DenonAVRVolume(DenonAVRFoundation):
             )
 
     async def async_channel_volume_down(self, channel: Channels) -> None:
-        """Decrease Channel volume on receiver via HTTP get command."""
+        """Decrease Channel volume on receiver."""
         self._is_valid_channel(channel)
 
-        mapped_channel = CHANNEL_MAP[channel]
+        mapped_channel = CHANNEL_MAP_REVERSE[channel]
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_channel_volume.format(
@@ -409,17 +406,17 @@ class DenonAVRVolume(DenonAVRFoundation):
 
     async def async_channel_volume(self, channel: Channels, volume: float) -> None:
         """
-        Set Channel volume on receiver via HTTP get command.
+        Set Channel volume on receiver.
 
         :param channel: Channel to set.
         :param volume: Volume to set. Valid values are -12 to 12 with 0.5 steps.
         """
         self._is_valid_channel(channel)
-        if volume not in CHANNEL_VOLUME_MAP_LABELS:
+        if volume not in CHANNEL_VOLUME_MAP_REVERSE:
             raise AvrCommandError(f"Invalid channel volume: {volume}")
 
-        mapped_channel = CHANNEL_MAP[channel]
-        mapped_volume = CHANNEL_VOLUME_MAP_LABELS[volume]
+        mapped_channel = CHANNEL_MAP_REVERSE[channel]
+        mapped_volume = CHANNEL_VOLUME_MAP_REVERSE[volume]
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_channel_volume.format(
@@ -434,7 +431,7 @@ class DenonAVRVolume(DenonAVRFoundation):
             )
 
     async def async_channel_volumes_reset(self) -> None:
-        """Reset all channel volumes on receiver via HTTP get command."""
+        """Reset all channel volumes on receiver."""
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_channel_volumes_reset
@@ -445,7 +442,7 @@ class DenonAVRVolume(DenonAVRFoundation):
             )
 
     async def async_subwoofer_on(self) -> None:
-        """Turn on Subwoofer on receiver via HTTP get command."""
+        """Turn on Subwoofer on receiver."""
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_subwoofer_on_off.format(mode="ON")
@@ -456,7 +453,7 @@ class DenonAVRVolume(DenonAVRFoundation):
             )
 
     async def async_subwoofer_off(self) -> None:
-        """Turn off Subwoofer on receiver via HTTP get command."""
+        """Turn off Subwoofer on receiver."""
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_subwoofer_on_off.format(mode="OFF")
@@ -468,7 +465,7 @@ class DenonAVRVolume(DenonAVRFoundation):
 
     async def async_subwoofer_toggle(self) -> None:
         """
-        Toggle Subwoofer on receiver via HTTP get command.
+        Toggle Subwoofer on receiver.
 
         Only available if using Telnet.
         """
@@ -478,9 +475,9 @@ class DenonAVRVolume(DenonAVRFoundation):
             await self.async_subwoofer_on()
 
     async def async_subwoofer_level_up(self, subwoofer: Subwoofers) -> None:
-        """Increase Subwoofer level on receiver via HTTP get command."""
+        """Increase Subwoofer level on receiver."""
         self._is_valid_subwoofer(subwoofer)
-        mapped_subwoofer = SUBWOOFERS_MAP[subwoofer]
+        mapped_subwoofer = SUBWOOFERS_MAP_REVERSE[subwoofer]
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_subwoofer_level.format(
@@ -495,9 +492,9 @@ class DenonAVRVolume(DenonAVRFoundation):
             )
 
     async def async_subwoofer_level_down(self, subwoofer: Subwoofers) -> None:
-        """Decrease Subwoofer level on receiver via HTTP get command."""
+        """Decrease Subwoofer level on receiver."""
         self._is_valid_subwoofer(subwoofer)
-        mapped_subwoofer = SUBWOOFERS_MAP[subwoofer]
+        mapped_subwoofer = SUBWOOFERS_MAP_REVERSE[subwoofer]
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_subwoofer_level.format(
@@ -512,7 +509,7 @@ class DenonAVRVolume(DenonAVRFoundation):
             )
 
     async def async_lfe_up(self) -> None:
-        """Increase LFE on receiver via HTTP get command."""
+        """Increase LFE on receiver."""
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_lfe.format(mode="UP")
@@ -523,7 +520,7 @@ class DenonAVRVolume(DenonAVRFoundation):
             )
 
     async def async_lfe_down(self) -> None:
-        """Decrease LFE on receiver via HTTP get command."""
+        """Decrease LFE on receiver."""
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_lfe.format(mode="DOWN")
@@ -535,7 +532,7 @@ class DenonAVRVolume(DenonAVRFoundation):
 
     async def async_lfe(self, lfe: int) -> None:
         """
-        Set LFE level on receiver via HTTP get command.
+        Set LFE level on receiver.
 
         :param lfe: LFE level to set. Valid values are -10 to 0.
         """
@@ -553,7 +550,7 @@ class DenonAVRVolume(DenonAVRFoundation):
             )
 
     async def async_bass_sync_up(self) -> None:
-        """Increase Bass Sync on receiver via HTTP get command."""
+        """Increase Bass Sync on receiver."""
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_bass_sync.format(mode="UP")
@@ -564,7 +561,7 @@ class DenonAVRVolume(DenonAVRFoundation):
             )
 
     async def async_bass_sync_down(self) -> None:
-        """Decrease Bass Sync on receiver via HTTP get command."""
+        """Decrease Bass Sync on receiver."""
         if self._device.telnet_available:
             await self._device.telnet_api.async_send_commands(
                 self._device.telnet_commands.command_bass_sync.format(mode="DOWN")
@@ -576,7 +573,7 @@ class DenonAVRVolume(DenonAVRFoundation):
 
     async def async_bass_sync(self, lfe: int) -> None:
         """
-        Set Bass Sync level on receiver via HTTP get command.
+        Set Bass Sync level on receiver.
 
         :param lfe: Bass Sync level to set. Valid values are -10 to 0.
         """
